@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.16';
+our $VERSION = '0.2.17';
 
 1;
 
@@ -635,6 +635,20 @@ Examples:
     # so on ...
 
 
+=head3 Dump task configuration
+
+You may dump task configuration using C<--dump-config> flag, no action will be performed,
+just task configuration data will be printed out in JSON format:
+
+    $ sparrow task run system/disk --dump-config
+
+Dump-config could be useful when copy some task configuration into other:
+
+    $ sparrow task run system/disk --dump-config > /tmp/system-disk.json
+    $ nano /tmp/system-disk.json
+    $ sparrow task load ini system/disk2 /tmp/system-disk.json
+
+
 =head2 Task boxes API
 
 Use this command to run task box
@@ -1025,6 +1039,13 @@ This is the way how one can declare dependencies for sparrow plugins:
 You should place a dependency file into a plugin root directory.
 
 
+=head1 Disable color output
+
+To every action you may optionally add C<--nocolor> flag to disable color output:
+
+    $ sparrow plg run df-check --nocolor
+
+
 =head1 Environment variables
 
 
@@ -1048,6 +1069,8 @@ Disable color output.
 
     $ export SPARROW_NO_COLOR=1
 
+Also see "Disable color output" section.
+
 
 =head1 Remote Tasks
 
@@ -1119,7 +1142,7 @@ Now only you can use app/passwords task.
 
 =head2 Add useful comments to task
 
-When doing remote task upload you optionaly can add a comment which will be show 
+When doing remote task upload you optionally can add a comment which will be show 
 when task gets listed with C<sparrow remote task list> command:
 
     $ sparrow remote task upload utils/nano-rc 'makes nano.rc setup'
@@ -1136,12 +1159,12 @@ To list your remote tasks ( both private and public ) say this:
 
 To get a list of available public remote tasks say this:
 
-    $ sparrow remote task public-list
+    $ sparrow remote task public list
 
 
 =head2 Remove remote task
 
-And finaly you can remove remote task:
+And finally you can remove remote task:
 
     $ sparrow remote task remove app/old-stuff
 
